@@ -16,8 +16,8 @@ import (
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 
-	gitalyClient "gitlab.com/gitlab-org/gitaly/v16/client"
-	pb "gitlab.com/gitlab-org/gitaly/v16/proto/go/gitalypb"
+	gitalyClient "gitlab.com/gitlab-org/gitaly/v18/client"
+	pb "gitlab.com/gitlab-org/gitaly/v18/proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/advanced/elastic"
 	"gitlab.com/gitlab-org/gitlab-elasticsearch-indexer/internal/mode/advanced/indexer"
 )
@@ -67,28 +67,6 @@ func init() {
 	}
 }
 
-func TestIndexingRenamesFiles(t *testing.T) {
-	checkDeps(t)
-	ensureGitalyRepository(t)
-	c, td := buildWorkingIndex(t, "project")
-
-	defer td()
-
-	// The commit before files/js/commit.js.coffee is renamed
-	_, err := run("", "281d3a76f31c812dbf48abce82ccf6860adedd81", schemaVersionBlobValueOption(), schemaVersionCommitValueOption(), projectIdOption())
-	require.NoError(t, err)
-	_, err = c.GetBlob("files/js/commit.js.coffee")
-	require.NoError(t, err)
-
-	// Now we expect it to have been renamed
-	_, err = run("281d3a76f31c812dbf48abce82ccf6860adedd81", "c347ca2e140aa667b968e51ed0ffe055501fe4f4", schemaVersionBlobValueOption(), schemaVersionCommitValueOption(), projectIdOption())
-	require.NoError(t, err)
-	_, err = c.GetBlob("files/js/commit.js.coffee")
-	require.Error(t, err)
-	_, err = c.GetBlob("files/js/commit.coffee")
-	require.NoError(t, err)
-}
-
 func ensureGitalyRepository(t *testing.T) {
 	conn, err := gitalyClient.Dial(gitalyConnInfo.Address, gitalyClient.DefaultDialOpts)
 	require.NoError(t, err)
@@ -270,6 +248,28 @@ func run(from, to string, args ...string) (string, error) {
 	return stdout.String(), err
 }
 
+func TestIndexingRenamesFiles(t *testing.T) {
+	checkDeps(t)
+	ensureGitalyRepository(t)
+	c, td := buildWorkingIndex(t, "project")
+
+	defer td()
+
+	// The commit before files/js/commit.js.coffee is renamed
+	_, err := run("", "281d3a76f31c812dbf48abce82ccf6860adedd81", schemaVersionBlobValueOption(), schemaVersionCommitValueOption(), projectIdOption())
+	require.NoError(t, err)
+	_, err = c.GetBlob("files/js/commit.js.coffee")
+	require.NoError(t, err)
+
+	// Now we expect it to have been renamed
+	_, err = run("281d3a76f31c812dbf48abce82ccf6860adedd81", "c347ca2e140aa667b968e51ed0ffe055501fe4f4", schemaVersionBlobValueOption(), schemaVersionCommitValueOption(), projectIdOption())
+	require.NoError(t, err)
+	_, err = c.GetBlob("files/js/commit.js.coffee")
+	require.Error(t, err)
+	_, err = c.GetBlob("files/js/commit.coffee")
+	require.NoError(t, err)
+}
+
 func TestIndexingRemovesFiles(t *testing.T) {
 	checkDeps(t)
 	ensureGitalyRepository(t)
@@ -307,6 +307,27 @@ func TestIndexingTimeout(t *testing.T) {
 	require.Regexp(t, `time: missing unit in duration`, stdout)
 }
 
+func TestIndexingWithSkipBlobs(t *testing.T) {
+	checkDeps(t)
+	ensureGitalyRepository(t)
+	c, td := buildWorkingIndex(t, "project")
+	defer td()
+
+	_, err := run("", headSHA, projectIdOption(), schemaVersionBlobValueOption(), schemaVersionCommitValueOption(), "--skip-blobs")
+	require.NoError(t, err)
+
+	// Check the commits are indexed
+	commit, err := c.GetCommit(headSHA)
+	require.NoError(t, err)
+	require.True(t, commit.Found)
+	require.Equal(t, projectIDString+"_"+headSHA, commit.Id)
+	require.Equal(t, "project_"+projectIDString, commit.Routing)
+
+	// Check the blobs are not indexed
+	_, err = c.GetBlob("README.md")
+	require.Error(t, err)
+}
+
 func TestIndexingFilesWithLongPath(t *testing.T) {
 	checkDeps(t)
 	ensureGitalyRepository(t)
