@@ -24,6 +24,7 @@ import (
 var (
 	versionFlag               = flag.Bool("version", false, "Print the version and exit")
 	skipCommitsFlag           = flag.Bool("skip-commits", false, "Skips indexing commits for the repo")
+	skipBlobsFlag             = flag.Bool("skip-blobs", false, "Skips indexing blobs for the repo")
 	blobTypeFlag              = flag.String("blob-type", "blob", "The type of blobs to index. Accepted values: 'blob', 'wiki_blob'")
 	visibilityLevelFlag       = flag.Int("visibility-level", -1, "Project or Group visibility_access_level. Accepted values: 0, 10, 20")
 	repositoryAccessLevelFlag = flag.Int("repository-access-level", -1, "Project repository_access_level. Accepted values: 0, 10, 20")
@@ -83,6 +84,7 @@ func Run(buildOpts shared.BuildOpts) error {
 	fromSHA := *fromSHAFlag
 	toSHA := *toSHAFlag
 	skipCommits := *skipCommitsFlag
+	skipBlobs := *skipBlobsFlag
 	fullPath := *fullPathFlag
 	timeoutOption := *timeoutOptionFlag
 	traversalIds := *traversalIdsFlag
@@ -181,6 +183,7 @@ func Run(buildOpts shared.BuildOpts) error {
 			"projectID":             esClient.ParentID(),
 			"blobType":              blobType,
 			"skipCommits":           skipCommits,
+			"skipBlobs":             skipBlobs,
 			"Permissions":           config.Permissions,
 			"PermissionsWiki":       config.PermissionsWiki,
 			"traversalIds":          traversalIds,
@@ -192,8 +195,10 @@ func Run(buildOpts shared.BuildOpts) error {
 		},
 	).Debugf("Indexing from %s to %s", client.FromHash, client.ToHash)
 
-	if err := idx.IndexBlobs(ctx, blobType); err != nil {
-		logkit.WithError(err).Fatalln("Indexing error")
+	if !skipBlobs {
+		if err := idx.IndexBlobs(ctx, blobType); err != nil {
+			logkit.WithError(err).Fatalln("Indexing error")
+		}
 	}
 
 	if !skipCommits && blobType == "blob" {
