@@ -74,6 +74,22 @@ func TestCreateChunker(t *testing.T) {
 	}
 }
 
+func testValidConnection[T types.Connection](t *testing.T, ctx context.Context, conn T, options Options) {
+	t.Helper()
+
+	connInfo := os.Getenv("ELASTIC_CONNECTION_INFO")
+	if connInfo == "" {
+		t.Skip("ELASTIC_CONNECTION_INFO not set")
+	}
+
+	err := json.Unmarshal([]byte(connInfo), &conn)
+	require.NoError(t, err, "failed to parse ELASTIC_CONNECTION_INFO")
+
+	indexer, err := createVectorStoreIndexer(ctx, conn, options)
+	require.NoError(t, err)
+	require.NotNil(t, indexer)
+}
+
 func TestCreateVectorStoreIndexer(t *testing.T) {
 	t.Parallel()
 
@@ -81,18 +97,13 @@ func TestCreateVectorStoreIndexer(t *testing.T) {
 	options := Options{PartitionName: "test", PartitionNumber: 1, ElasticBulkSize: 100}
 
 	t.Run("elasticsearch connection", func(t *testing.T) {
-		connInfo := os.Getenv("ELASTIC_CONNECTION_INFO")
-		if connInfo == "" {
-			t.Skip("ELASTIC_CONNECTION_INFO not set")
-		}
-
 		var esConn types.ElasticsearchConnection
-		err := json.Unmarshal([]byte(connInfo), &esConn)
-		require.NoError(t, err, "failed to parse ELASTIC_CONNECTION_INFO")
+		testValidConnection(t, ctx, esConn, options)
+	})
 
-		indexer, err := createVectorStoreIndexer(ctx, esConn, options)
-		require.NoError(t, err)
-		require.NotNil(t, indexer)
+	t.Run("opensearch connection", func(t *testing.T) {
+		var osConn types.OpenSearchConnection
+		testValidConnection(t, ctx, osConn, options)
 	})
 
 	t.Run("postgresql adapter not implemented", func(t *testing.T) {
@@ -102,13 +113,6 @@ func TestCreateVectorStoreIndexer(t *testing.T) {
 		require.Contains(t, err.Error(), "indexing not implemented for adapter: postgresql")
 	})
 
-	t.Run("opensearch adapter not implemented", func(t *testing.T) {
-		osConn := types.OpenSearchConnection{URL: []string{"http://localhost:9200"}}
-		_, err := createVectorStoreIndexer(ctx, osConn, options)
-		require.Error(t, err)
-		require.Contains(t, err.Error(), "indexing not implemented for adapter: opensearch")
-	})
-
 	t.Run("unknown adapter type", func(t *testing.T) {
 		_, err := createVectorStoreIndexer(ctx, mockUnknownConnection{}, options)
 		require.Error(t, err)
